# Internet Open Sources used to elaborate CaloriesTracker

## Food components

* https://www.healthline.com/nutrition/how-much-protein-per-day#average-needs
* https://www.tuasaude.com/es/calorias-de-los-alimentos/

## Indicators calculations

* https://www.seedo.es/index.php/pacientes/calculo-imc


## Additives

* https://www.aditivos-alimentarios.com/
* https://eur-lex.europa.eu/legal-content/ES/TXT/?uri=celex%3A32011R1129#d1e34-5-1
* http://www.fao.org/gsfaonline/additives/index.html?lang=es
* https://e-aditivos.com/
* http://www.aecosan.msssi.gob.es/AECOSAN/web/para_el_consumidor/ampliacion/aditivos.htm
* https://www.who.int/es/news-room/fact-sheets/detail/food-additives
